@@ -1,9 +1,10 @@
-maximise.likelihood <- function(model=stop("Please specify a distribution"), data=stop("Data must be specified"), mean=NA, variance=NA, zi=NA, shape=NA, scale=NA, silent=FALSE){
+maximise.likelihood <- function(data=stop("Data must be specified"), model=stop("Please specify a distribution"), mean=NA, variance=NA, zi=NA, shape=NA, scale=NA, silent=FALSE){
+	
+	model <- toupper(model)
+	testdata <- data
 	
-	if(silent==FALSE) cat("\n")
-
 	models <- c("P", "ZIP", "G", "ZIG", "L", "ZIL", "W", "ZIW", "GP", "ZIGP", "LP", "ZILP", "WP", "ZIWP")
-
+		
 	if((length(model) != 1) |  sum(is.na(model)) > 0 | sum(model==models)!=1){
 		if(silent==FALSE){
 			cat("Invalid model selection.  Please choose from ONE of the following distributions: ", sep="")
@@ -13,6 +14,8 @@ maximise.likelihood <- function(model=stop("Please specify a distribution"), dat
 		stop("Invalid model selection")
 	}
 	
+	if(silent==FALSE) cat("\n")
+	
 	if(sum(is.na(data)) > 0){
 		if(silent==FALSE) cat("WARNING:  Missing data was removed before calculating the likelihood\n\n")
 		data <- na.omit(data)
@@ -20,7 +23,14 @@ maximise.likelihood <- function(model=stop("Please specify a distribution"), dat
 	
 	guitest <- testJAGS(silent=TRUE)
 	
-	if(guitest$R.GUI == "AQUA" & guitest$R.package.type == "mac.binary") eol <- "" else eol <- "                  \n"
+	#if(guitest$os=='windows' | (guitest$R.GUI == "AQUA" & guitest$R.package.type == "mac.binary")) eol <- "" else eol <- "                  \n"
+	if(guitest$R.GUI == "AQUA" & guitest$R.package.type == "mac.binary"){
+		clearline <- ""
+		eol <- "\n"
+	}else{
+		clearline <- "\r                                                         \r"
+		eol <- "\t\t"
+	}
 	
 	if(silent==FALSE){
 		cat("Maximising the likelihood for the '", model, "' model.  This may take some time\n")
@@ -34,7 +44,7 @@ maximise.likelihood <- function(model=stop("Please specify a distribution"), dat
 		}else{
 			cat("\n\tmean\n", eol, "\t", signif(mean+(mean/100000), 4), eol, sep="")
 			f <- function(mean){
-				cat("\b\r\t", signif(mean+(mean/100000), 4), eol, sep="")
+				cat(clearline, "\t", signif(mean+(mean/100000), 4), eol, sep="")
 				return(likelihood(model=model, data=data, mean=mean, silent=TRUE))
 			}
 		}
@@ -55,7 +65,7 @@ maximise.likelihood <- function(model=stop("Please specify a distribution"), dat
 			cat("\n\tmean\t\tzi\n", eol, "\t", signif(mean+(mean/100000), 4), "\t\t", signif(zi+(zi/100000), 4), eol, sep="")
 			f <- function(pars=c(NA, NA)){
 				if(pars[2] < 0 | pars[2] > 100 | pars[1] < 0) return(-Inf)
-				cat("\b\r\t", signif(pars[1]+(pars[1]/100000), 4), "\t\t", signif(pars[2]+(pars[2]/100000), 4), eol, sep="")
+				cat(clearline, "\t", signif(pars[1]+(pars[1]/100000), 4), "\t\t", signif(pars[2]+(pars[2]/100000), 4), eol, sep="")
 				return(likelihood(model=model, data=data, mean=pars[1], zi=pars[2], silent=TRUE))
 			}
 		}
@@ -76,7 +86,7 @@ maximise.likelihood <- function(model=stop("Please specify a distribution"), dat
 			cat("\n\tshape\t\tscale\n", eol, "\t", signif(shape, 4), "\t\t", signif(scale, 4), eol, sep="")
 			f <- function(pars=c(NA, NA)){
 				if(pars[2] <= 0 | pars[1] <= 0) return(-Inf)
-				cat("\b\r\t", signif(pars[1], 4), "\t\t", signif(pars[2], 4), eol, sep="")
+				cat(clearline, "\t", signif(pars[1], 4), "\t\t", signif(pars[2], 4), eol, sep="")
 				return(likelihood(model=model, data=data, shape=pars[1], scale=pars[2], silent=TRUE))
 			}
 		}
@@ -98,7 +108,7 @@ maximise.likelihood <- function(model=stop("Please specify a distribution"), dat
 			cat("\n\tshape\t\tscale\t\tzi\n", eol, "\t", signif(shape, 4), "\t\t", signif(scale, 4), "\t\t", signif(zi, 4), eol, sep="")
 			f <- function(pars=c(NA, NA, NA)){
 				if(pars[2] <= 0 | pars[1] <= 0 | pars[3] < 0 | pars[3] > 100) return(-Inf)
-				cat("\b\r\t", signif(pars[1], 4), "\t\t", signif(pars[2], 4), "\t\t", signif(pars[3], 4), eol, sep="")
+				cat(clearline, "\t", signif(pars[1], 4), "\t\t", signif(pars[2], 4), "\t\t", signif(pars[3], 4), eol, sep="")
 				return(likelihood(model=model, data=data, shape=pars[1], scale=pars[2], zi=pars[3], silent=TRUE))
 			}
 		}
@@ -119,7 +129,7 @@ maximise.likelihood <- function(model=stop("Please specify a distribution"), dat
 			cat("\n\tshape\t\tscale\n", eol, "\t", signif(shape, 4), "\t\t", signif(scale, 4), eol, sep="")
 			f <- function(pars=c(NA, NA)){
 				if(pars[2] <= 0 | pars[1] <= 0) return(-Inf)
-				cat("\b\r\t", signif(pars[1], 4), "\t\t", signif(pars[2], 4), eol, sep="")
+				cat(clearline, "\t", signif(pars[1], 4), "\t\t", signif(pars[2], 4), eol, sep="")
 				return(likelihood(model=model, data=data, shape=pars[1], scale=pars[2], silent=TRUE))
 			}
 		}
@@ -141,7 +151,7 @@ maximise.likelihood <- function(model=stop("Please specify a distribution"), dat
 			cat("\n\tshape\t\tscale\t\tzi\n", eol, "\t", signif(shape, 4), "\t\t", signif(scale, 4), "\t\t", signif(zi, 4), eol, sep="")
 			f <- function(pars=c(NA, NA, NA)){
 				if(pars[2] <= 0 | pars[1] <= 0 | pars[3] < 0 | pars[3] > 100) return(-Inf)
-				cat("\b\r\t", signif(pars[1], 4), "\t\t", signif(pars[2], 4), "\t\t", signif(pars[3], 4), eol, sep="")
+				cat(clearline, "\t", signif(pars[1], 4), "\t\t", signif(pars[2], 4), "\t\t", signif(pars[3], 4), eol, sep="")
 				return(likelihood(model=model, data=data, shape=pars[1], scale=pars[2], zi=pars[3], silent=TRUE))
 			}
 		}
@@ -162,7 +172,7 @@ maximise.likelihood <- function(model=stop("Please specify a distribution"), dat
 			cat("\n\tmean\t\tvariance\n", eol, "\t", signif(mean, 4), "\t\t", signif(variance, 4), eol, sep="")
 			f <- function(pars=c(NA, NA)){
 				if(pars[2] <= 0 | pars[1] < 0) return(-Inf)
-				cat("\b\r\t", signif(pars[1], 4), "\t\t", signif(pars[2], 4), eol, sep="")
+				cat(clearline, "\t", signif(pars[1], 4), "\t\t", signif(pars[2], 4), eol, sep="")
 				return(likelihood(model=model, data=data, mean=pars[1], variance=pars[2], silent=TRUE))
 			}
 		}
@@ -184,7 +194,7 @@ maximise.likelihood <- function(model=stop("Please specify a distribution"), dat
 			cat("\n\tmean\t\tvariance\t\tzi\n", eol, "\t", signif(mean, 4), "\t\t", signif(variance, 4), "\t\t", signif(zi, 4), eol, sep="")
 			f <- function(pars=c(NA, NA, NA)){
 				if(pars[2] < 0 | pars[1] < 0 | pars[3] < 0 | pars[3] > 100) return(-Inf)
-				cat("\b\r\t", signif(pars[1], 4), "\t\t", signif(pars[2], 4), "\t\t", signif(pars[3], 4), eol, sep="")
+				cat(clearline, "\t", signif(pars[1], 4), "\t\t", signif(pars[2], 4), "\t\t", signif(pars[3], 4), eol, sep="")
 				return(likelihood(model=model, data=data, mean=pars[1], variance=pars[2], zi=pars[3], silent=TRUE))
 			}
 		}
@@ -193,8 +203,8 @@ maximise.likelihood <- function(model=stop("Please specify a distribution"), dat
 	}
 	
 	if(silent==FALSE){
-		if(guitest$R.GUI == "AQUA" & guitest$R.package.type == "mac.binary") cat("\n")
-		cat("\nFinished maximising the likelihood\n\n")
+		#if(guitest$R.GUI == "AQUA" & guitest$R.package.type == "mac.binary") cat("\n")
+		cat("\n\nFinished maximising the likelihood\n\n")
 	}
 	return(results)
 }
\ No newline at end of file
